/*  
    BluePhone is a Bluetooth mobile phone manager
    Copyright (C) 2004 Ed Rayne <er241@cam.ac.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <gtk/gtk.h>	

#include "support.h"
#include "eggtrayicon.h"
#include "global.h"
#include "docklet.h"

static gboolean docklet_clicked_cb (GtkWidget *widget, GdkEventButton *event);
static gboolean docklet_destroyed_cb (GtkWidget *widget, GdkEvent *event);

static EggTrayIcon *docklet;
static GtkWidget *menu;

void
create_docklet (void)
{
	GtkWidget *box;
	GtkWidget *image;
	GdkPixbuf *pixbuf;
	GdkPixbuf *scaled;

	docklet = egg_tray_icon_new ("BluePhone");

	box = gtk_event_box_new ();
	pixbuf = create_pixbuf ("bluephone/phone.png");
	scaled = gdk_pixbuf_scale_simple (pixbuf, 24, 24, GDK_INTERP_HYPER);
	image = gtk_image_new_from_pixbuf (scaled);

	gtk_container_add (GTK_CONTAINER (box), image);
	gtk_container_add (GTK_CONTAINER (docklet), box);

	menu = create_docklet_menu ();
	
	gtk_widget_show_all (GTK_WIDGET (docklet));

	/* attach signals */
	g_signal_connect (G_OBJECT (box), "button_press_event", 
			  G_CALLBACK (docklet_clicked_cb), NULL);
	g_signal_connect (G_OBJECT (docklet), "destroy-event",
			  G_CALLBACK (docklet_destroyed_cb), NULL);
	
	g_object_ref (G_OBJECT(docklet));
}

static gboolean
docklet_clicked_cb (GtkWidget *widget, GdkEventButton *event)
{
	if (event->type != GDK_BUTTON_PRESS)
	{
		return FALSE;
	}
	if (event->button == 1)
	{
		/* show/hide main window */
	}
	else if (event->button == 3)
	{
		gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL,
				NULL, event->button, event->time);
		return TRUE;
	}
	return FALSE;
}

static gboolean
docklet_destroyed_cb (GtkWidget *widget, GdkEvent *event)
{
	return TRUE;
}
