/*  
    BluePhone is a Bluetooth mobile phone manager
    Copyright (C) 2004 Ed Rayne <er241@cam.ac.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>
#include <gconf/gconf-client.h>
#include <bluetooth/bluetooth.h>
#include <obex.h>

#include "interface.h"
#include "support.h"
#include "bluetooth.h"
#include "global.h"
#include "docklet.h"

static gint rfcommchannel = 0;
static gchar *btaddress = NULL;

static const struct poptOption options[] =
{
	{
		"address", 
		'\0', 
		POPT_ARG_STRING, 
		&btaddress, 
		0,
		N_("Bluetooth device address"),
		"00:00:00:00:00:00"
	},
	{
		"rfcomm",
		'\0',
		POPT_ARG_INT,
		&rfcommchannel,
		0,
		N_("Channel for RFCOMM"),
		N_("CHANNEL")
	},
	{
		NULL,
		'\0',
		0,
		NULL,
		0
	}
};

static void get_gconf_data (void);
static void set_gconf_data (void);

static void
set_gconf_data (void)
{
	GConfClient *client;

	client = gconf_client_get_default ();

	if (rfcommchannel != 0)
		gconf_client_set_int (client, "/apps/bluephone/rfcomm", rfcommchannel, NULL);
	if (btaddress != NULL)
		gconf_client_set_string (client, "/apps/bluephone/address", btaddress, NULL);
}

static void
get_gconf_data (void)
{
	GConfClient *client;
	gchar *address;
	
	client = gconf_client_get_default ();
	
	address = gconf_client_get_string (client, "/apps/bluephone/address", NULL);
	str2ba (address, &(global.bdaddr));
	global.rfcomm = gconf_client_get_int (client, "/apps/bluephone/rfcomm", NULL);
}

int
main (int argc, char *argv[])
{
	
#ifdef ENABLE_NLS
	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
	textdomain (GETTEXT_PACKAGE);
#endif

	gnome_program_init (PACKAGE, VERSION, LIBGNOMEUI_MODULE, argc, argv,
			    GNOME_PARAM_POPT_TABLE, options,
	                    GNOME_PARAM_APP_DATADIR, PACKAGE_DATA_DIR,
	                    NULL);

	/* deal with arguments */
	set_gconf_data ();
	
	/* get preference data from gconf if it exists */
	get_gconf_data ();
	
	/* add a timeout to monitor connection status every 10s */
	gtk_timeout_add (TIMEOUT, (GtkFunction) rfcomm_connect, NULL);

	create_docklet ();

	gtk_main ();
	
	if (global.socket)
		close (global.socket);
	
	return 0;
}

